盗梦空间 (豆瓣)
Description: 盗梦空间电影简介和剧情介绍,盗梦空间影评、图片、预告片、影讯、论坛、在线购票
Keywords: 盗梦空间,Inception,盗梦空间影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.9豆瓣电影Top250

# 盗梦空间 Inception (2010)

更新描述或海报

导演: 克里斯托弗·诺兰
编剧: 克里斯托弗·诺兰
主演: 莱昂纳多·迪卡普里奥 / 约瑟夫·高登-莱维特 / 艾利奥特·佩吉 / 汤姆·哈迪 / 渡边谦 / 迪利普·劳 / 基里安·墨菲 / 汤姆·贝伦杰 / 玛丽昂·歌迪亚 / 皮特·波斯尔思韦特 / 迈克尔·凯恩 / 卢卡斯·哈斯 / 李太力 / 克莱尔·吉尔蕾 / 马格努斯·诺兰 / 泰勒·吉蕾 / 乔纳森·吉尔 / 水源士郎 / 冈本玉二 / 厄尔·卡梅伦 / 瑞恩·海沃德 / 米兰达·诺兰 / 拉什·费加 / 蒂姆·科勒赫 / 妲露拉·莱莉
类型: 剧情 / 科幻 / 悬疑 / 冒险
制片国家/地区: 美国 / 英国
语言: 英语 / 日语 / 法语
上映日期: 2010-09-01(中国大陆) / 2020-08-28(中国大陆重映) / 2010-07-16(美国)
片长: 148分钟
又名: 潜行凶间(港) / 全面启动(台) / 奠基 / 心灵犯案 / 记忆迷阵 / 记忆魔方
IMDb: tt1375666
官方小站: 盗梦空间-Inception
豆瓣评分
引用
9.4
1965439人评价
5星
72.3%
4星
23.9%
3星
3.5%
2星
0.2%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
7.3
6人评价
好于 99% 科幻片
好于 99% 悬疑片
我看过这部电影 2020-07-15 修改
我的评价:
推荐

## 盗梦空间的剧情简介 · · · · · ·

道姆·柯布（莱昂纳多·迪卡普里奥 Leonardo DiCaprio 饰）与同事阿瑟（约瑟夫·戈登-莱维特 Joseph Gordon-Levitt 饰）和纳什（卢卡斯·哈斯 Lukas Haas 饰）在一次针对日本能源大亨齐藤（渡边谦 饰）的盗梦行动中失败，反被齐藤利用。齐藤威逼利诱因遭通缉而流亡海外的柯布帮他拆分他竞争对手的公司，采取极端措施在其唯一继承人罗伯特·费希尔（希里安·墨菲 Cillian Murphy 饰）的深层潜意识中种下放弃家族公司、自立门户的想法。为了重返美国，柯布偷偷求助于岳父迈尔斯（迈克尔·凯恩 Michael Caine 饰），吸收了年轻的梦境设计师艾里阿德妮（艾伦·佩吉 Ellen Page 饰）、梦境演员艾姆斯（汤姆·哈迪 Tom Hardy 饰）和药剂师约瑟夫（迪利普·劳 Dileep Rao 饰）加入行动。在一层层... (展开全部) 道姆·柯布（莱昂纳多·迪卡普里奥 Leonardo DiCaprio 饰）与同事阿瑟（约瑟夫·戈登-莱维特 Joseph Gordon-Levitt 饰）和纳什（卢卡斯·哈斯 Lukas Haas 饰）在一次针对日本能源大亨齐藤（渡边谦 饰）的盗梦行动中失败，反被齐藤利用。齐藤威逼利诱因遭通缉而流亡海外的柯布帮他拆分他竞争对手的公司，采取极端措施在其唯一继承人罗伯特·费希尔（希里安·墨菲 Cillian Murphy 饰）的深层潜意识中种下放弃家族公司、自立门户的想法。为了重返美国，柯布偷偷求助于岳父迈尔斯（迈克尔·凯恩 Michael Caine 饰），吸收了年轻的梦境设计师艾里阿德妮（艾伦·佩吉 Ellen Page 饰）、梦境演员艾姆斯（汤姆·哈迪 Tom Hardy 饰）和药剂师约瑟夫（迪利普·劳 Dileep Rao 饰）加入行动。在一层层递进的梦境中，柯布不仅要对付费希尔潜意识的本能反抗，还必须直面已逝妻子梅尔（玛丽昂·歌迪亚 Marion Cotillard 饰）的处处破坏，实际情况远比预想危险得多…… ©豆瓣

## 盗梦空间的演职员 · · · · · · ( 全部 47 )

- 克里斯托弗·诺兰 导演
- 莱昂纳多·迪卡普里奥 饰 柯布 Cobb
- 约瑟夫·高登-莱维特 饰 阿瑟 Arthur
- 艾利奥特·佩吉 饰 艾里阿德妮 Ariadne
- 汤姆·哈迪 饰 艾姆斯 Eames
- 渡边谦 饰 齐藤 Saito

## 盗梦空间的视频和图片 · · · · · · ( 预告片12 | 添加视频评论 | 图片1168 · 添加 )

## 盗梦空间的获奖情况 · · · · · · ( 全部 )

- 第83届奥斯卡金像奖
- 最佳影片(提名)
- 艾玛·托马斯 / 克里斯托弗·诺兰

- 第68届金球奖
- 电影类 最佳剧情片(提名)

- 第34届日本电影学院奖
- 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  致命魔术

  黑客帝国

  源代码

  蝴蝶效应

  阿凡达

  星际穿越

  禁闭岛

  记忆碎片

  看不见的客人

  头号玩家

我要写短评

## 盗梦空间的短评 · · · · · · ( 全部 388037 条 )

热门 / 最新 / 好友

### 47716 有用 山风如月 看过 2010-09-01 10:06:31

大概广电局也不知道该从哪里剪

### 12310 有用 大宸 看过 2010-07-31 22:49:13

卡梅隆负责革新电影技术，诺兰负责革新电影结构...

### 10153 有用 路北辰 看过 2010-07-15 21:54:25

一部电影好看到即使你明白它在故弄玄虚也是义无反顾的打五星。

### 6521 有用 陈允然 看过 2010-07-17 13:34:58

我的陀螺停不下来了。

### 5271 有用 影志 看过 2010-08-26 17:31:32

“既然做梦，就做大点” 这句太深得人心了。——2010年最天才的电影。“谁又能说，现实不是梦境。” Do you remember how you got here?

> 更多短评 388037条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 黑烟的圈 看过 2020-01-05 11:55:50

导演想在我们心中植入一个观念。

### 0 有用 苏打的小鬼头 看过 2020-08-12 11:16:30

原本以为按照导演的名气和其拍的很好的追随 会很不错的的 还是期望过高了 几层梦境空间原本可以有更好的发挥 起码在我看来大师拍的应该更有说服力 但现实就是通过莫名其妙的枪战、硬生生推出一条家庭线和迷宫炫技来托显影片的厉害 着实让人看的非常累 以至于看完不能再思考 可好可不好 说好的站在好的角度 但混乱且用力过重是我很难接受的 要是像楚门的世界般讲讲人生也好啊 弄了太多看头反倒不知道在讲什么了 过度的... 原本以为按照导演的名气和其拍的很好的追随 会很不错的的 还是期望过高了 几层梦境空间原本可以有更好的发挥 起码在我看来大师拍的应该更有说服力 但现实就是通过莫名其妙的枪战、硬生生推出一条家庭线和迷宫炫技来托显影片的厉害 着实让人看的非常累 以至于看完不能再思考 可好可不好 说好的站在好的角度 但混乱且用力过重是我很难接受的 要是像楚门的世界般讲讲人生也好啊 弄了太多看头反倒不知道在讲什么了 过度的展开便忘了源起 (展开)

### 0 有用 LLudeer 看过 2018-10-15 13:31:51

大概要在电影院看才有感觉吧

我要写影评

## 盗梦空间的影评 · · · · · · ( 全部 6626 条 )

热门 / 最新 / 好友
文艺复兴人 2010-07-16 20:40:54

## Inception 情节逻辑完全解析

Inception 情节逻辑完全解析 （有不明白地方的进，没看过的别进） Inception 情节逻辑完全解析 （有不明白地方的进，没看过的别进） Inception就好象是玄幻小说，你必须接受它里面的无数天马行空的设定；但是它是最好的玄幻小说，因为在它的设定下情节无懈可击。所以... (展开)
18863 940 3754回应 收起
Wiö 2010-09-03 03:06:05

## IMDb上翻译的影评！戒指是关键！

这篇影评可能有剧透

** WARNING: This is long, and every word of it contains spoilers. Beware ** **注意：这很长，文章每个字都是剧透。慎入** It is NOT a dream: The WEDDING RING gives it away. 这不是个梦：婚戒泄露了真相 I have now seen this movie three times. The first time... (展开)
9270 225 853回应 收起
高斯控 2010-07-22 04:47:08

## Inception中的数学原理和逻辑(严重剧透，但考虑到多数人一张票的钱只够猜迷，没法欣赏，还是发了吧）

这篇影评可能有剧透

（ 新有一篇写的比我这篇中的数学分析更具体。 http://bbs.hoopchina.com/1009/1525287.html 我觉得一些东西是相通的， 那篇读者理解起来可能更形像 推荐给大家。 也许诺兰没学数学，读了那本书。 MIT 还有一个课件。 http://ocw.mit.edu/high-school/courses/godel-escher-ba... (展开)
6253 1145 1479回应 收起
何倩彤 2010-08-15 20:56:22

## IMDB花絮+破绽全翻译

★★★花絮部份★★★ 　　 　　 有关电影制作背后： 　　 ◆《Inception》其实早在2003年拍完《白夜追凶》时便已想投给华纳制作。而华纳也确实答应了。但当时剧本都还没写好。而Nolan也觉得不该把它当成一件差事来做，而是该慢慢的把它写好，写好了再找公司发行就行了。... (展开)
1589 108 271回应 收起
脑洞要比脑门大 2010-07-21 03:06:34

## 看完两遍后的解析和感受（大量剧透）

这篇影评可能有剧透

开头 影片开头老saito和cobb的对话和之后小saito办晚宴不是一起的。老saito那段是结尾cobb去limbo拯救他，而小saito的晚宴是saito的梦，梦里cobb被cobol engineering派去盗取saito的秘密。Saito事后告诉他们，其实那段盗取记忆是他在audition他们，当时那个architect没过关，... (展开)
1446 199 426回应 收起
Monlina 2010-07-20 10:08:14

## 丈夫，我醒了，我没有跳下去。

我是中国人，他是美国人。 我们在一起5年，结婚5个月。 7月17号晚上，刚从北京度假回来的我和丈夫一起坐在Cinemark里，专注地看《Inception》。 当Cobb的妻子要跳下去的时候，当他撕心裂肺地喊着“No!”的时候，我转过头看着我的丈夫。 他的眼眶湿了。我于是紧紧地握住他的手... (展开)
1741 176 314回应 收起
ParasItE 2010-07-19 09:19:58

## 现实并不存在，只是我们，陷在其中。

这篇影评可能有剧透

序幕 大学时候深陷EVA和御姐情结作祟的深恋葛城美里，让我转遍了上海的小市场淘到了一个当时看来很高仿的不锈钢十字架，系着黑色的线，这些年无论我走到哪里，面对着哪一个陌生的天花板，我都会把它放在枕头底下。有一次想不起前因后果的在床上醒来，枕头上自己的头发一根根的... (展开)
862 127 203回应 收起
张佳玮 2010-09-06 19:33:32

## 这电影还真不只是单靠天才创意玄妙灵感就能拍出来上映的

看《盗梦空间》时脑子里依次不讲道理瞎蹦出来的，简略摘：《黑客帝国》，郑渊洁老师《第3180号专利》里的做梦帽，《世界尽头冷酷仙境》里“世界尽头”的虚拟世界构筑，埃舍尔楼梯，黄粱，庄周梦蝶，博尔赫斯的《双梦记》和《南方》以及其他名字忘掉意境类似的东西，《爱德华大... (展开)
670 48 97回应 收起
水木丁 2010-09-12 13:11:14

## 谁人畏惧现实，谁将在梦中将自己迷失（非技术分析，无剧透）

和COCO小姐一起去看《盗梦空间》，没有想象的那么复杂，关于技术的问题，我们只是出来以后简单的交换了几个情节，其他的到是很好理解。看电影的过程中，COCO小姐问我，你说如果咱俩坐在电影院里是场梦，醒来以后发现自己在家呢怎么办，我说那到不可怕，怕的就是醒来以后发现自... (展开)
467 36 82回应 收起
Anthony 2010-09-05 12:06:20

## 《盗梦空间》结局解析

这篇影评可能有剧透

建议看完的人再来看这。有不对的可以说出来，毕竟我也不敢我是对的。有很多人说《盗梦空间》还是在梦里，是个悲剧。又有很多人说这是诺兰的开放式结局，但是诺兰向来不用开放式这种方式来结局。其实结局是柯布回到了现实，两点证据，证据一：科布他一直忘不了妻子，一直以自己... (展开)
628 57 345回应 收起

> 更多影评 6626篇

添加新讨论

## 讨论区 · · · · · ·

个人想法：用《盗梦空间》的逻辑解释《红楼梦》 | 来自June | 87 回应 | 2022-11-23 07:56:43
简单证明不存在第四层梦境（重写主贴） | 来自boymax | 1645 回应 | 2022-11-22 22:31:28
小李子和他老婆不是在迷失域白头偕老了吗，为什么... | 来自彡穆穆彡 |  | 2022-11-22 22:22:51
梦 | 来自凌草 |  | 2022-11-20 15:34:08
★★★全网最完整、最详实的诺兰抄袭辟谣帖！★★★ | 来自JayNolan | 58 回应 | 2022-11-19 18:13:19

> 去这部影片的讨论区（全部2749条）

## 关于《盗梦空间》的问题 · · · · · · ( 全部111个 )

- 这部电影被过誉了么？ 21人回答
- 你们有做过梦中梦吗？ 24人回答

> 全部111个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 爱奇艺视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【意外结局】 (影志)
- 2011 豆瓣电影【口碑榜】 (影志)
- {北美电影票房总排行} (荔枝超人)
- 经典商业与法律电影 (passionfly)

## 谁在看这部电影 · · · · · ·

- Guofy
  刚刚 看过
- 枫叶zs
  1分钟前 想看
- Murphy's law
  3分钟前 看过

3451579人看过 / 416043人想看

订阅盗梦空间的评论:
feed: rss 2.0